==> payroll_ver_3.2.1.zip: payroll3/pub/system/js/workTypeMasterCard.js <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2009 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
/**
 * ʓǍǉ
 * @param 
 * @return 
 * @throws sO
 */
function onLoadExtra() {
	// ڔwiFݒ
	setFieldsBgColor(ARY_FIELDS_ID    , COLOR_FIELD_NORMAL);
	setFieldsBgColor(ARY_ERR_FIELDS_ID, COLOR_FIELD_ERROR );
	// ڒݒ
	setMaxLength(PRM_TXT_SHIFT_CODE 		, LEN_SHIFT_CODE);
	setMaxLength(PRM_TXT_SHIFT_NAME 		, LEN_SHIFT_NAME);
	setMaxLength(PRM_TXT_START_HOUR 		, LEN_TIME);
	setMaxLength(PRM_TXT_START_MIN 			, LEN_TIME);
	setMaxLength(PRM_TXT_QUIT_HOUR 			, LEN_TIME);
	setMaxLength(PRM_TXT_QUIT_MIN 			, LEN_TIME);
	setMaxLength(PRM_TXT_WORK_HOUR 			, LEN_TIME);
	setMaxLength(PRM_TXT_WORK_MIN 			, LEN_TIME);
	setMaxLength(PRM_TXT_BREAK_HOUR 		, LEN_TIME);
	setMaxLength(PRM_TXT_BREAK_MIN 			, LEN_TIME);
	setMaxLength(PRM_TXT_OVER_START_HOUR 	, LEN_TIME);
	setMaxLength(PRM_TXT_OVER_START_MIN 	, LEN_TIME);
	setMaxLength(PRM_TXT_OVER_BREAK_HOUR 	, LEN_TIME);
	setMaxLength(PRM_TXT_OVER_BREAK_MIN 	, LEN_TIME);
	// o^/XV
	if (MODE == 0) {
		// ǎpݒ
		setReadOnly(PRM_PLT_DELETE  	, true);
		setReadOnly(PRM_TXT_WORK_HOUR  	, true);
		setReadOnly(PRM_TXT_WORK_MIN  	, true);
		// tH[JXݒ
		setFocus(PRM_TXT_SHIFT_CODE);
	} else if (MODE == 1) {
		// ǎpݒ
		setReadOnly(PRM_TXT_SHIFT_CODE  , true);
		setReadOnly(PRM_TXT_WORK_HOUR  	, true);
		setReadOnly(PRM_TXT_WORK_MIN  	, true);
		// tH[JXݒ
		setFocus(PRM_TXT_SHIFT_NAME);
	}
	// VKo^{^p
	if (MODE != 1){
		setObjectVisibility("btnNewData", false);	
		setWidth("btnNewData", 0);
	}
}

/**
 * T[o[ʐM
 * @param 
 * @return 
 * @throws sO
 */
function submitForm(objForm) {
	// ̓`FbN
	if (validate()) {
		// T[o[ʐM(̓G[̏ꍇ)
		if (MODE == 0) {
			doSubmitMessage(objForm, 'S2607', 'QC0001', '');
		} else if (MODE == 1) {
			doSubmitMessage(objForm, 'S2608', 'QC0001', '');
		}
	}
}

/**
 * ̓`FbN
 * @param 
 * @return `FbN(trueFOKAfalseFNG)
 * @throws sO
 */
function validate() {
	// tB[hwiFݒ
	setFieldsBgColor(ARY_FIELDS_ID, COLOR_FIELD_NORMAL);
	// ̓`FbN
	var aryMessage = new Array();
	checkRequired(PRM_TXT_SHIFT_CODE		, NAM_SHIFT_CODE			, aryMessage);
	checkRequired(PRM_TXT_SHIFT_NAME		, NAM_SHIFT_NAME			, aryMessage);
	checkRequired(PRM_TXT_START_HOUR		, NAM_START_TIME_HOUR		, aryMessage);
	checkRequired(PRM_TXT_START_MIN			, NAM_START_TIME_MIN		, aryMessage);
	checkRequired(PRM_TXT_QUIT_HOUR			, NAM_QUIT_TIME_HOUR		, aryMessage);
	checkRequired(PRM_TXT_QUIT_MIN			, NAM_QUIT_TIME_MIN			, aryMessage);
	checkRequired(PRM_TXT_WORK_HOUR			, NAM_WORKING_HOURS_HOUR	, aryMessage);
	checkRequired(PRM_TXT_WORK_MIN			, NAM_WORKING_HOURS_MIN		, aryMessage);
	checkRequired(PRM_TXT_BREAK_HOUR		, NAM_BREAK_TIME_HOUR		, aryMessage);
	checkRequired(PRM_TXT_BREAK_MIN			, NAM_BREAK_TIME_MIN		, aryMessage);
	checkRequired(PRM_TXT_OVER_START_HOUR	, NAM_OVERTIME_START_HOUR	, aryMessage);
	checkRequired(PRM_TXT_OVER_START_MIN	, NAM_OVERTIME_START_MIN	, aryMessage);
	checkRequired(PRM_TXT_OVER_BREAK_HOUR	, NAM_OVERTIME_BREAK_HOUR	, aryMessage);
	checkRequired(PRM_TXT_OVER_BREAK_MIN	, NAM_OVERTIME_BREAK_MIN	, aryMessage);
	
	checkCode    (PRM_TXT_SHIFT_CODE , NAM_SHIFT_CODE, aryMessage);
	
	checkNumber  (PRM_TXT_START_HOUR		, NAM_START_TIME_HOUR		, aryMessage);
	checkNumber  (PRM_TXT_START_MIN			, NAM_START_TIME_MIN		, aryMessage);
	checkNumber  (PRM_TXT_QUIT_HOUR			, NAM_QUIT_TIME_HOUR		, aryMessage);
	checkNumber  (PRM_TXT_QUIT_MIN			, NAM_QUIT_TIME_MIN			, aryMessage);
	checkNumber  (PRM_TXT_BREAK_HOUR		, NAM_BREAK_TIME_HOUR		, aryMessage);
	checkNumber  (PRM_TXT_BREAK_MIN			, NAM_BREAK_TIME_MIN		, aryMessage);
	checkNumber  (PRM_TXT_OVER_START_HOUR	, NAM_OVERTIME_START_HOUR	, aryMessage);
	checkNumber  (PRM_TXT_OVER_START_MIN	, NAM_OVERTIME_START_MIN	, aryMessage);
	checkNumber  (PRM_TXT_OVER_BREAK_HOUR	, NAM_OVERTIME_BREAK_HOUR	, aryMessage);
	checkNumber  (PRM_TXT_OVER_BREAK_MIN	, NAM_OVERTIME_BREAK_MIN	, aryMessage);

	checkLength(PRM_TXT_SHIFT_CODE 		, LEN_SHIFT_CODE 	, NAM_SHIFT_CODE			, aryMessage);
	checkLength(PRM_TXT_SHIFT_NAME 		, LEN_SHIFT_NAME 	, NAM_SHIFT_NAME			, aryMessage);
	checkLength(PRM_TXT_START_HOUR 		, LEN_TIME 			, NAM_START_TIME_HOUR		, aryMessage);
	checkLength(PRM_TXT_START_MIN 		, LEN_TIME 			, NAM_START_TIME_MIN		, aryMessage);
	checkLength(PRM_TXT_QUIT_HOUR 		, LEN_TIME 			, NAM_QUIT_TIME_HOUR		, aryMessage);
	checkLength(PRM_TXT_QUIT_MIN 		, LEN_TIME 			, NAM_QUIT_TIME_MIN			, aryMessage);
	checkLength(PRM_TXT_WORK_HOUR 		, LEN_TIME 			, NAM_WORKING_HOURS_HOUR	, aryMessage);
	checkLength(PRM_TXT_WORK_MIN 		, LEN_TIME 			, NAM_WORKING_HOURS_MIN		, aryMessage);
	checkLength(PRM_TXT_BREAK_HOUR 		, LEN_TIME 			, NAM_BREAK_TIME_HOUR		, aryMessage);
	checkLength(PRM_TXT_BREAK_MIN 		, LEN_TIME 			, NAM_BREAK_TIME_MIN		, aryMessage);
	checkLength(PRM_TXT_OVER_START_HOUR , LEN_TIME 			, NAM_OVERTIME_START_HOUR	, aryMessage);
	checkLength(PRM_TXT_OVER_START_MIN 	, LEN_TIME 			, NAM_OVERTIME_START_MIN	, aryMessage);
	checkLength(PRM_TXT_OVER_BREAK_HOUR , LEN_TIME 			, NAM_OVERTIME_BREAK_HOUR	, aryMessage);
	checkLength(PRM_TXT_OVER_BREAK_MIN 	, LEN_TIME 			, NAM_OVERTIME_BREAK_MIN	, aryMessage);
	//ԁA̍vl`FbN
	checkTimeValue(PRM_TXT_START_HOUR		,PRM_TXT_START_MIN		, 24 , NAM_START_TIME		,aryMessage);
	checkTimeValue(PRM_TXT_QUIT_HOUR		,PRM_TXT_QUIT_MIN		, 48 , NAM_QUIT_TIME		,aryMessage);
	checkTimeValue(PRM_TXT_BREAK_HOUR		,PRM_TXT_BREAK_MIN		, 24 , NAM_BREAK_TIME		,aryMessage);
	checkTimeValue(PRM_TXT_OVER_START_HOUR	,PRM_TXT_OVER_START_MIN	, 48 , NAM_OVERTIME_START	,aryMessage);
	checkTimeValue(PRM_TXT_OVER_BREAK_HOUR	,PRM_TXT_OVER_BREAK_MIN	, 24 , NAM_OVERTIME_BREAK	,aryMessage);

	var start 	= getFormValue(PRM_TXT_START_HOUR) * 60 + eval(getFormValue(PRM_TXT_START_MIN));
	var quit 	= getFormValue(PRM_TXT_QUIT_HOUR)  * 60 + eval(getFormValue(PRM_TXT_QUIT_MIN));
	if (quit < start) {
		setBgColor(PRM_TXT_START_HOUR, COLOR_FIELD_ERROR);
		setBgColor(PRM_TXT_START_MIN, COLOR_FIELD_ERROR);
		setBgColor(PRM_TXT_QUIT_HOUR, COLOR_FIELD_ERROR);
		setBgColor(PRM_TXT_QUIT_MIN, COLOR_FIELD_ERROR);
		aryMessage.push(getMessage("WC2028", NAM_START_TIME + "," + NAM_QUIT_TIME));
	}
	
	setFormValue(PRM_TXT_WORK_HOUR, Math.floor(eval((quit - start) / 60)));
	setFormValue(PRM_TXT_WORK_MIN, eval((quit - start) % 60));

	var breakHour = getFormValue(PRM_TXT_BREAK_HOUR);
	var breakMin  = getFormValue(PRM_TXT_BREAK_MIN);
	if ((quit - start) < (breakHour * 60 + eval(breakMin))) {
		setBgColor(PRM_TXT_BREAK_HOUR, COLOR_FIELD_ERROR);
		setBgColor(PRM_TXT_BREAK_MIN, COLOR_FIELD_ERROR);
		aryMessage.push(getMessage("WC2028", NAM_BREAK_TIME + "," + NAM_WORKING_HOURS));
	}
	
	if (aryMessage.length == 0) {
		return true;
	} else {
		showMessage(aryMessage);
		return false;
	}
}

==> payroll_ver_3.3.0.zip: payroll3/pub/system/js/workTypeMasterCard.js <==
/*
 * MosP - Mind Open Source Project    http://www.mosp.jp/
 * Copyright (C) MIND Co., Ltd.       http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
/**
 * ʓǍǉ
 * @param 
 * @return 
 * @throws sO
 */
function onLoadExtra() {
	// ڔwiFݒ
	setFieldsBgColor(ARY_FIELDS_ID    , COLOR_FIELD_NORMAL);
	setFieldsBgColor(ARY_ERR_FIELDS_ID, COLOR_FIELD_ERROR );
	// ڒݒ
	setMaxLength(PRM_TXT_SHIFT_CODE 		, LEN_SHIFT_CODE);
	setMaxLength(PRM_TXT_SHIFT_NAME 		, LEN_SHIFT_NAME);
	setMaxLength(PRM_TXT_START_HOUR 		, LEN_TIME);
	setMaxLength(PRM_TXT_START_MIN 			, LEN_TIME);
	setMaxLength(PRM_TXT_QUIT_HOUR 			, LEN_TIME);
	setMaxLength(PRM_TXT_QUIT_MIN 			, LEN_TIME);
	setMaxLength(PRM_TXT_WORK_HOUR 			, LEN_TIME);
	setMaxLength(PRM_TXT_WORK_MIN 			, LEN_TIME);
	setMaxLength(PRM_TXT_BREAK_HOUR 		, LEN_TIME);
	setMaxLength(PRM_TXT_BREAK_MIN 			, LEN_TIME);
	//setMaxLength(PRM_TXT_OVER_START_HOUR 	, LEN_TIME);
	//setMaxLength(PRM_TXT_OVER_START_MIN 	, LEN_TIME);
	//setMaxLength(PRM_TXT_OVER_BREAK_HOUR 	, LEN_TIME);
	//setMaxLength(PRM_TXT_OVER_BREAK_MIN 	, LEN_TIME);
	// o^/XV
	if (MODE == 0) {
		// ǎpݒ
		setReadOnly(PRM_PLT_DELETE  	, true);
		setReadOnly(PRM_TXT_WORK_HOUR  	, true);
		setReadOnly(PRM_TXT_WORK_MIN  	, true);
		// tH[JXݒ
		setFocus(PRM_TXT_SHIFT_CODE);
	} else if (MODE == 1) {
		// ǎpݒ
		setReadOnly(PRM_TXT_SHIFT_CODE  , true);
		setReadOnly(PRM_TXT_WORK_HOUR  	, true);
		setReadOnly(PRM_TXT_WORK_MIN  	, true);
		// tH[JXݒ
		setFocus(PRM_TXT_SHIFT_NAME);
	}
	// VKo^{^p
	if (MODE != 1){
		setObjectVisibility("btnNewData", false);	
		setWidth("btnNewData", 0);
	}
}

/**
 * T[o[ʐM
 * @param 
 * @return 
 * @throws sO
 */
function submitForm(objForm) {
	// ̓`FbN
	if (validate()) {
		// T[o[ʐM(̓G[̏ꍇ)
		if (MODE == 0) {
			doSubmitMessage(objForm, 'S2607', 'QC0001', '');
		} else if (MODE == 1) {
			doSubmitMessage(objForm, 'S2608', 'QC0001', '');
		}
	}
}

/**
 * ̓`FbN
 * @param 
 * @return `FbN(trueFOKAfalseFNG)
 * @throws sO
 */
function validate() {
	// tB[hwiFݒ
	setFieldsBgColor(ARY_FIELDS_ID, COLOR_FIELD_NORMAL);
	// ̓`FbN
	var aryMessage = new Array();
	checkRequired(PRM_TXT_SHIFT_CODE		, NAM_SHIFT_CODE			, aryMessage);
	checkRequired(PRM_TXT_SHIFT_NAME		, NAM_SHIFT_NAME			, aryMessage);
	checkRequired(PRM_TXT_START_HOUR		, NAM_START_TIME_HOUR		, aryMessage);
	checkRequired(PRM_TXT_START_MIN			, NAM_START_TIME_MIN		, aryMessage);
	checkRequired(PRM_TXT_QUIT_HOUR			, NAM_QUIT_TIME_HOUR		, aryMessage);
	checkRequired(PRM_TXT_QUIT_MIN			, NAM_QUIT_TIME_MIN			, aryMessage);
	checkRequired(PRM_TXT_WORK_HOUR			, NAM_WORKING_HOURS_HOUR	, aryMessage);
	checkRequired(PRM_TXT_WORK_MIN			, NAM_WORKING_HOURS_MIN		, aryMessage);
	checkRequired(PRM_TXT_BREAK_HOUR		, NAM_BREAK_TIME_HOUR		, aryMessage);
	checkRequired(PRM_TXT_BREAK_MIN			, NAM_BREAK_TIME_MIN		, aryMessage);
	//checkRequired(PRM_TXT_OVER_START_HOUR	, NAM_OVERTIME_START_HOUR	, aryMessage);
	//checkRequired(PRM_TXT_OVER_START_MIN	, NAM_OVERTIME_START_MIN	, aryMessage);
	//checkRequired(PRM_TXT_OVER_BREAK_HOUR	, NAM_OVERTIME_BREAK_HOUR	, aryMessage);
	//checkRequired(PRM_TXT_OVER_BREAK_MIN	, NAM_OVERTIME_BREAK_MIN	, aryMessage);
	
	checkCode    (PRM_TXT_SHIFT_CODE , NAM_SHIFT_CODE, aryMessage);
	
	checkNumber  (PRM_TXT_START_HOUR		, NAM_START_TIME_HOUR		, aryMessage);
	checkNumber  (PRM_TXT_START_MIN			, NAM_START_TIME_MIN		, aryMessage);
	checkNumber  (PRM_TXT_QUIT_HOUR			, NAM_QUIT_TIME_HOUR		, aryMessage);
	checkNumber  (PRM_TXT_QUIT_MIN			, NAM_QUIT_TIME_MIN			, aryMessage);
	checkNumber  (PRM_TXT_BREAK_HOUR		, NAM_BREAK_TIME_HOUR		, aryMessage);
	checkNumber  (PRM_TXT_BREAK_MIN			, NAM_BREAK_TIME_MIN		, aryMessage);
	//checkNumber  (PRM_TXT_OVER_START_HOUR	, NAM_OVERTIME_START_HOUR	, aryMessage);
	//checkNumber  (PRM_TXT_OVER_START_MIN	, NAM_OVERTIME_START_MIN	, aryMessage);
	//checkNumber  (PRM_TXT_OVER_BREAK_HOUR	, NAM_OVERTIME_BREAK_HOUR	, aryMessage);
	//checkNumber  (PRM_TXT_OVER_BREAK_MIN	, NAM_OVERTIME_BREAK_MIN	, aryMessage);

	checkLength(PRM_TXT_SHIFT_CODE 		, LEN_SHIFT_CODE 	, NAM_SHIFT_CODE			, aryMessage);
	checkLength(PRM_TXT_SHIFT_NAME 		, LEN_SHIFT_NAME 	, NAM_SHIFT_NAME			, aryMessage);
	checkLength(PRM_TXT_START_HOUR 		, LEN_TIME 			, NAM_START_TIME_HOUR		, aryMessage);
	checkLength(PRM_TXT_START_MIN 		, LEN_TIME 			, NAM_START_TIME_MIN		, aryMessage);
	checkLength(PRM_TXT_QUIT_HOUR 		, LEN_TIME 			, NAM_QUIT_TIME_HOUR		, aryMessage);
	checkLength(PRM_TXT_QUIT_MIN 		, LEN_TIME 			, NAM_QUIT_TIME_MIN			, aryMessage);
	checkLength(PRM_TXT_WORK_HOUR 		, LEN_TIME 			, NAM_WORKING_HOURS_HOUR	, aryMessage);
	checkLength(PRM_TXT_WORK_MIN 		, LEN_TIME 			, NAM_WORKING_HOURS_MIN		, aryMessage);
	checkLength(PRM_TXT_BREAK_HOUR 		, LEN_TIME 			, NAM_BREAK_TIME_HOUR		, aryMessage);
	checkLength(PRM_TXT_BREAK_MIN 		, LEN_TIME 			, NAM_BREAK_TIME_MIN		, aryMessage);
	//checkLength(PRM_TXT_OVER_START_HOUR , LEN_TIME 			, NAM_OVERTIME_START_HOUR	, aryMessage);
	//checkLength(PRM_TXT_OVER_START_MIN 	, LEN_TIME 			, NAM_OVERTIME_START_MIN	, aryMessage);
	//checkLength(PRM_TXT_OVER_BREAK_HOUR , LEN_TIME 			, NAM_OVERTIME_BREAK_HOUR	, aryMessage);
	//checkLength(PRM_TXT_OVER_BREAK_MIN 	, LEN_TIME 			, NAM_OVERTIME_BREAK_MIN	, aryMessage);
	//ԁA̍vl`FbN
	checkTimeValue(PRM_TXT_START_HOUR		,PRM_TXT_START_MIN		, 24 , NAM_START_TIME		,aryMessage);
	checkTimeValue(PRM_TXT_QUIT_HOUR		,PRM_TXT_QUIT_MIN		, 48 , NAM_QUIT_TIME		,aryMessage);
	checkTimeValue(PRM_TXT_BREAK_HOUR		,PRM_TXT_BREAK_MIN		, 24 , NAM_BREAK_TIME		,aryMessage);
	//checkTimeValue(PRM_TXT_OVER_START_HOUR	,PRM_TXT_OVER_START_MIN	, 48 , NAM_OVERTIME_START	,aryMessage);
	//checkTimeValue(PRM_TXT_OVER_BREAK_HOUR	,PRM_TXT_OVER_BREAK_MIN	, 24 , NAM_OVERTIME_BREAK	,aryMessage);

	var start 	= getFormValue(PRM_TXT_START_HOUR) * 60 + eval(getFormValue(PRM_TXT_START_MIN));
	var quit 	= getFormValue(PRM_TXT_QUIT_HOUR)  * 60 + eval(getFormValue(PRM_TXT_QUIT_MIN));
	if (quit < start) {
		setBgColor(PRM_TXT_START_HOUR, COLOR_FIELD_ERROR);
		setBgColor(PRM_TXT_START_MIN, COLOR_FIELD_ERROR);
		setBgColor(PRM_TXT_QUIT_HOUR, COLOR_FIELD_ERROR);
		setBgColor(PRM_TXT_QUIT_MIN, COLOR_FIELD_ERROR);
		aryMessage.push(getMessage("WC2028", NAM_START_TIME + "," + NAM_QUIT_TIME));
	}
	
	setFormValue(PRM_TXT_WORK_HOUR, Math.floor(eval((quit - start) / 60)));
	setFormValue(PRM_TXT_WORK_MIN, eval((quit - start) % 60));

	var breakHour = getFormValue(PRM_TXT_BREAK_HOUR);
	var breakMin  = getFormValue(PRM_TXT_BREAK_MIN);
	if ((quit - start) < (breakHour * 60 + eval(breakMin))) {
		setBgColor(PRM_TXT_BREAK_HOUR, COLOR_FIELD_ERROR);
		setBgColor(PRM_TXT_BREAK_MIN, COLOR_FIELD_ERROR);
		aryMessage.push(getMessage("WC2028", NAM_BREAK_TIME + "," + NAM_WORKING_HOURS));
	}
	
	if (aryMessage.length == 0) {
		return true;
	} else {
		showMessage(aryMessage);
		return false;
	}
}
